==> nextcloud-21.0.8p0.tgz: nextcloud/apps/comments/l10n/pt_PT.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentários",
    "You commented" : "Comentou",
    "%1$s commented" : "%1$s comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Comentaste em %1$s",
    "You commented on {file}" : "Comentaste em {file}",
    "%1$s commented on %2$s" : "%1$s comentou %2$s",
    "{author} commented on {file}" : "{author} comentou em {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> aos ficheiros",
    "Files app plugin to add comments to files" : "Plugin de aplicação de ficheiros para adicionar comentários aos ficheiros",
    "Edit comment" : "Editar comentário",
    "Delete comment" : "Eliminar comentário",
    "No comments yet, start the conversation!" : "Ainda sem comentários, inicie uma conversação!",
    "Retry" : "Repetir",
    "_%n unread comment_::_%n unread comments_" : ["%n comentários por ler","%n comentários por ler"],
    "_1 new comment_::_{unread} new comments_" : ["1 novo comentário","{unread} novos comentários"],
    "Comment" : "Comentário",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Foste mencionado e, “{file}”, num comentário de um utilizador que foi entretanto removido",
    "{user} mentioned you in a comment on “{file}”" : "{user} mencionou-te num comentário em “{file}”",
    "New comment …" : "Novo comentário …",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Utilizador eliminado]",
    "More comments …" : "Mais comentários ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "{count} de {max} caracteres restantes",
    "Error occurred while retrieving comment with ID {id}" : "Ocorreu um erro durante a obtenção do comentário com ID {id}",
    "Error occurred while updating comment with id {id}" : "Ocorreu um erro ao tentar atualizar o comentário com o id {id}",
    "Error occurred while posting comment" : "Ocorreu um erro ao tentar publicar o comentário"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/comments/l10n/pt_PT.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentários",
    "You commented" : "Comentou",
    "%1$s commented" : "%1$s comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Comentaste em %1$s",
    "You commented on {file}" : "Comentaste em {file}",
    "%1$s commented on %2$s" : "%1$s comentou %2$s",
    "{author} commented on {file}" : "{author} comentou em {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> aos ficheiros",
    "Files app plugin to add comments to files" : "Plugin de aplicação de ficheiros para adicionar comentários aos ficheiros",
    "Edit comment" : "Editar comentário",
    "Delete comment" : "Eliminar comentário",
    "No comments yet, start the conversation!" : "Ainda sem comentários, inicie uma conversação!",
    "Retry" : "Repetir",
    "_%n unread comment_::_%n unread comments_" : ["%n comentários por ler","%n comentários por ler","%n comentários por ler"],
    "_1 new comment_::_{unread} new comments_" : ["1 novo comentário","{unread} novos comentários","{unread} novos comentários"],
    "Comment" : "Comentário",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Foste mencionado e, “{file}”, num comentário de um utilizador que foi entretanto removido",
    "{user} mentioned you in a comment on “{file}”" : "{user} mencionou-te num comentário em “{file}”"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
